@@ -17,8 +17,10 @@
 /*
 /*	The result is overwritten with each call.
 /*
-/*	A null argv0 argument requests that the current
-/*	result is returned.
+/*	A null argv0 argument requests that the current result is
+/*	returned.
+/* DIAGNOSTICS
+/*	Panic: argv0 is a null pointer, but no current result exists.
 /* LICENSE
 /* .ad
 /* .fi
@@ -44,6 +46,7 @@
 
 #include <vstring.h>
 #include <safe.h>
+#include <msg.h>
 
 /* Global library. */
 
@@ -71,5 +74,7 @@ const char *mail_task(const char *argv0)
 		mail_conf_eval(DEF_SYSLOG_NAME);
 	vstring_sprintf(canon_name, "%s/%s", tag, argv0);
     }
+    if (canon_name == 0)
+	msg_panic("mail_task: no current result");
     return (vstring_str(canon_name));
 }
